<?php
/* DaumView plugin for Textcube 1.8.X
   ----------------------------------
   Version 1.3.1
   Tatter and Media Dev Team.

   Creator          : park jae-sun, yupmin
   Maintainer       : yupmin
   Contributor      : 도아, 위즈
   Modify(Ver 1.3.1) by Gunmania

   Created at       : 2007.
   Last modified at : 2013.09.10
 
 General Public License
 http://www.gnu.org/licenses/gpl.html

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
*/

function DaumView_getAttachmentExtract($content){
	$result = null;
	if(preg_match_all('/\[##_(1R|1L|1C|2C|3C|iMazing|Gallery)\|[^|]*\.(gif|jpg|jpeg|png|bmp|GIF|JPG|JPEG|PNG|BMP)\|.*_##\]/si', $content, $matches)) {
		$split = explode("|", $matches[0][0]);
		$result = $split[1];
	}else if(preg_match_all('/<img[^>]+?src=("|\')?([^\'">]*?)("|\')/si', $content, $matches)) {
		if( stristr($matches[2][0], 'http://') ){
			$result = $matches[2][0];
		}
	}
	return $result;
}

function DaumView_getResampleImageByWidth($blogid, $fileName, $maxWidth = 150) {
	$context = Model_Context::getInstance();

	$filenames = explode('.',$fileName);
	if (count($filenames) <= 1) return false;
	$imageName = array_shift($filenames);
	$imageExt = array_pop($filenames);
	$imageFileName =  "{$imageName}.{$imageExt}";

	if (!in_array($imageExt, array('jpg','gif','png'))) return false;

	$resamplePath = $imagePath = ROOT . "/attach/{$blogid}/{$imageFileName}";
	$resampleURL = "{$context->getProperty('uri.service')}/attach/{$blogid}/{$imageFileName}";

	if (file_exists($imagePath)) {
		$imageInfo = getimagesize($imagePath);
		if ($imageInfo[0] >= $maxWidth) {
			$resampleWidth = $maxWidth;
			$resampleHeight = intval($resampleWidth * $imageInfo[1] / $imageInfo[0]);
			if ($resampleWidth == 0 || $resampleHeight == 0) return false;

			$imageFileName = "{$imageName}.w{$resampleWidth}-h{$resampleHeight}.{$imageExt}";

			$resamplePath = ROOT."/cache/thumbnail/{$blogid}/{$imageFileName}";
			$resampleURL = "{$context->getProperty('uri.service')}/cache/thumbnail/{$blogid}/{$imageFileName}";

			if(!file_exists($resamplePath)) {
				$AttachedImage = new Image();
				$AttachedImage->imageFile = $imagePath;
				if ($AttachedImage->resample($resampleWidth, $resampleHeight)) {
					// 리샘플링된 파일 저장.
					if(!$AttachedImage->createThumbnailIntoFile($resamplePath)) return false;
				}
				unset($AttachedImage);
			}
		}
	} else return false;
	return $resampleURL;
}

function DaumView_setDaumview($categoryid, $channel, $entryid) {
	global $user;

	$context = Model_Context::getInstance();
	$data = DBModel::getInstance();
	$blogid = $context->getProperty('blog.id');
	$userid = $user['id'];
//	$userid = $context->getProperty('user.id');

	if(empty($entryid)) {
		$data->reset('DaumView');
		$data->setAttribute('blogid', $blogid);
		$data->setAttribute('entryid', 0);
		$data->setAttribute('userid', $userid);
		$data->setAttribute('categoryid', $categoryid, true);
		$data->setAttribute('channel', $channel, true);
		$data->setAttribute('send', 0);
		return $data->replace();
	}
    $data->reset('DaumView');
    $data->setQualifier('blogid','eq',$blogid);
	$data->setQualifier('entryid','eq',$entryid);
    $daumview = $data->getRow();

	// 새로, 임시 작성된 글에 카테고리 정하기(entryid이 0일때)
	if (!is_null($daumview) && $daumview['send'] == 0 ) {
		$data->reset('DaumView');
		$data->setAttribute('categoryid', $categoryid, true);
		$data->setAttribute('channel', $channel, true);
	    $data->setQualifier('blogid','eq',$blogid);
		$data->setQualifier('entryid','eq',$entryid);
		return $data->update();
	// ok인 상태
	} else if( !is_null($daumview) && $daumview['send'] > 0  ) {
		return true;
	// 정보조차 없을때 
	} else {
		$data->reset('DaumView');
		$data->setAttribute('blogid', $blogid);
		$data->setAttribute('entryid', $entryid);
		$data->setAttribute('userid', $userid);
		$data->setAttribute('categoryid', $categoryid, true);
		$data->setAttribute('channel', $channel, true);
		return $data->insert();
	}
	return false;
}

function DaumView_syncDaumview($entryid){

	if(!Validator::id($entryid) ) return false;
	$context = Model_Context::getInstance();
	$blogid = $context->getProperty('blog.id');

	$data = DBModel::getInstance();
    $data->reset('DaumView');
    $data->setQualifier('blogid','eq',$blogid);
	$data->setQualifier('entryid','eq',$entryid);
    $daumview = $data->getRow();

	if(is_null($daumview) || (isset($daumview['channel']) && empty($daumview['channel']))) return false;

	$trackback_result = DaumView_sendTrackback($blogid, $entryid, "http://v.daum.net/trackback/{$daumview['channel']}");

	if ($trackback_result) {
		$data->reset('DaumView');
		$data->setAttribute('send', Timestamp::getUNIXtime());
		$data->setQualifier('blogid', 'eq', $blogid);
		$data->setQualifier('entryid', 'eq', $entryid);
		$daumview_result = $data->update();
	} else $daumview_result = false;
	return ($trackback_result && $daumview_result); 
}

function DaumView_deleteDaumview($entryid) {
	if( !Validator::id($entryid) ) return false;

	$context = Model_Context::getInstance();
	$data = DBModel::getInstance();
	$data->reset('DaumView');
	$data->setQualifier('blogid', 'eq', $context->getProperty('blog.id'));
	$data->setQualifier('entryid', 'eq', $entryid);
	return $data->delete();
}

/* DaumView_getDaumviewidByPermalink
   퍼머링크로 DaumView id 및 업데이트 날짜를 업데이트를 한다 그리고 DaumView id를 반환한다.
*/
function DaumView_getDaumviewidByPermalink($entryid, $permaLink=false){
	requireModel('reader.common');

	$context = Model_Context::getInstance();
	$blogid = $context->getProperty('blog.id');
	$entry = getEntry($blogid, $entryid);
	// 다음View측 퍼머링크 처리
	$entry['slogan'] = iconv('UTF-8','EUC-KR', $entry['slogan']);
	$permalink = $context->getProperty('uri.default').'/'.($context->getProperty('blog.useSloganOnPost') ? "entry/" . URL::encode($entry['slogan'],0) : $entry['id']);

	requireComponent("Eolin.PHP.HTTPRequest");	
	$apiURL = "http://api.v.daum.net/open/news_info.xml";
	$params = "permlink=".rawurlencode($permalink);
	$request = new HTTPRequest('GET', $apiURL.'?'.$params);
	$request->contentType = 'application/x-www-form-urlencoded; charset=utf-8';
	$request->timeout = 1;
	$request->referer = !isset($_SERVER['HTTP_REFERER'])? '' : $_SERVER['HTTP_REFERER'];

	if($request->send()) {
		$xml = $request->responseText;
		$xmls = new XMLStruct();
		$xmls->open($xml, 'EUC-KR');

		$field = $xmls->selectNodes('/result/head/code');
		$code = $field[0]['.value'];
		if($code == "200") {
			$field = $xmls->selectNodes('/result/entity/news');
			$blognewsid = $field[0]['id'][0]['.value'];
			$categoryid = $field[0]['category_id'][0]['.value'];
			$reg_date = parseDate($field[0]["reg_date"][0]['.value']);

			// 값을 가지고 와서 DB에 저장
			if( Validator::id($blognewsid) && Validator::isInteger($reg_date) && !empty($categoryid)){
				$data = DBModel::getInstance();
				$data->reset('DaumView');
				$data->setQualifier('blogid', 'eq', $blogid);
				$data->setQualifier('entryid', 'eq', $entryid);
				
				if(!$data->doesExist()) {
					$data->reset('Entries');
					$data->setQualifier('blogid', 'eq', $blogid);
					$data->setQualifier('id', 'eq', $entryid);
					$entry = $data->getRow();

					$data->reset('DaumView');
					$data->setAttribute('blogid', $blogid);
					$data->setAttribute('userid', $entry['userid']);
					$data->setAttribute('entryid', $entryid);
					$data->setAttribute('send', $reg_date);
					$data->insert();
				}

				$categories = DaumView_getCategories();
				if(empty($categories)) return false;
				$category = $categories[$categoryid];
				$data->reset('DaumView');
				$data->setAttribute('blognewsid', $blognewsid);
				$data->setAttribute('blognewsid_checked', Timestamp::getUNIXtime());
				$data->setAttribute('categoryid', $categoryid, true);
				$data->setAttribute('channel', isset($category['channel'])?$category['channel']:'', true);
				$data->setQualifier('blogid', 'eq', $blogid);
				$data->setQualifier('entryid', 'eq', $entryid);
				$data->update();

				return $blognewsid;
			}
		}
	}
	return false;
}

/* DaumView_getChannels
   DaumView 채널을 가지고 와서 캐쉬화 한다.
*/
function DaumView_getChannels() {
	requireComponent('Needlworks.Cache.PageCache');
	$cache = new PageCache;
	$cache->name = 'daumview_category_xml';
	if($cache->load()) { //If successful loads
		if((time() - $cache->dbContents) < 3600 * 24)	// refresh time check
			return $cache->contents;
	}

	requireComponent("Eolin.PHP.HTTPRequest");	
	$request = new HTTPRequest('http://api.v.daum.net/open/category.xml');
	$request->timeout = 1;
	$request->referer = !isset($_SERVER['HTTP_REFERER'])? '' : $_SERVER['HTTP_REFERER'];
	$xml = $request->send()? $request->responseText : null;

	$cache->contents = $xml;
	$cache->dbContents = Timestamp::getUNIXtime();
	$cache->update();
	unset($cache);

	return $xml;
}
/* DaumView_getCategories
   DaumView 채널에서 필요한것만 카테고리화 한다
*/
function DaumView_getCategories() {
	$xml = DaumView_getChannels();
	$xmls = new XMLStruct();
	if (!$xmls->open($xml, 'EUC-KR'))
		return false;

	if ($xmls->getValue('/result/head/code') != "200")
		return false;

	$result = array();
	$one_depth_categories = $xmls->selectNodes('/result/entity/category');
	foreach($one_depth_categories as $one_depth_category) {
		foreach($one_depth_category['list'][0]['category'] as $two_depth_category) {
			$id = $two_depth_category['id'][0]['.value'];
			$url = $two_depth_category['url'][0]['.value'];
			$channel = $two_depth_category['category_name'][0]['.value'];
			$result[$id] = array('channel' => $channel);
		}
	}
	return $result;
}

function DaumView_getDaumviewid($entryid){
	if(!Validator::id($entryid)) return null;

	$context = Model_Context::getInstance();
	$data = DBModel::getInstance();
    $data->reset('DaumView');
    $data->setQualifier('blogid','eq',$context->getProperty('blog.id'));
	$data->setQualifier('entryid','eq',$entryid);
    $daumview = $data->getRow();
	if(is_null($daumview) || (isset($daumview['blognewsid']) && empty($daumview['blognewsid']))) {
		$daumviewid = DaumView_getDaumviewidByPermalink($entryid);
		if($daumviewid === false) $daumviewid = null;
	} else
		$daumviewid = $daumview['blognewsid'];
	return $daumviewid;
}

function DaumView_sendTrackback($blogid, $entryId, $url) {
	global $blog;
	requireModel('blog.entry');
	requireModel('blog.keyword');
	
	$entry = getEntry($blogid, $entryId);
	if (is_null($entry)) return false;
	$context = Model_Context::getInstance();

	$link = $context->getProperty('uri.default').'/'.($context->getProperty('blog.useSloganOnPost') ? "entry/" . URL::encode($entry['slogan'],0) : $entry['id']);

	$title = htmlspecialchars($entry['title']);
	$entry['content'] = getEntryContentView($blogid, $entryId, $entry['content'], $entry['contentformatter'], getKeywordNames($blogid));
	$excerpt = str_tag_on(UTF8::lessen(removeAllTags(stripHTML($entry['content'])), 255));
	$blogTitle = $blog['title'];

	$imgUrl = '';
	if($imageUrl = DaumView_getAttachmentExtract($entry['content'])) {
		$imageName = array_pop(explode('/',$imageUrl));
		$imgUrl = DaumView_getResampleImageByWidth($blogid, $imageName);
	}

	$isNeedConvert = 
		strpos($url, '/rserver.php?') !== false // 구버전 태터
		|| strpos($url, 'blog.naver.com/tb') !== false // 네이버 블로그
		|| strpos($url, 'news.naver.com/tb/') !== false // 네이버 뉴스
		|| strpos($url, 'blog.empas.com') !== false // 엠파스 블로그
		|| strpos($url, 'blog.yahoo.com') !== false // 야후 블로그
		|| strpos($url, 'www.blogin.com/tb/') !== false // 블로긴
		|| strpos($url, 'cytb.cyworld.nate.com') !== false // 싸이 페이퍼
		|| strpos($url, 'www.cine21.com/Movies/tb.php') !== false // cine21
		;
	if ($isNeedConvert) {
		$title = UTF8::convert($title, 'EUC-KR');
		$excerpt = UTF8::convert($excerpt, 'EUC-KR');
		$blogTitle = UTF8::convert($blogTitle, 'EUC-KR');
		$content = "url=" . rawurlencode($link) . "&title=" . rawurlencode($title) . "&blog_name=" . rawurlencode($blogTitle) . "&excerpt=" . rawurlencode($excerpt) . (!empty($imgUrl) ? "&img_url=" .rawurlencode($imgUrl):'');
		$request = new HTTPRequest('POST', $url);
		$request->contentType = 'application/x-www-form-urlencoded; charset=euc-kr';
		$isSuccess = $request->send($content);
	} else {
		$content = "url=" . rawurlencode($link) . "&title=" . rawurlencode($title) . "&blog_name=" . rawurlencode($blogTitle) . "&excerpt=" . rawurlencode($excerpt) . (!empty($imgUrl) ? "&img_url=" .rawurlencode($imgUrl):'');
		$request = new HTTPRequest('POST', $url);
		$request->contentType = 'application/x-www-form-urlencoded; charset=utf-8';
		$isSuccess = $request->send($content);
	}

	if ($isSuccess && (checkResponseXML($request->responseText) === 0)) {
//		$url = POD::escapeString(UTF8::lessenAsEncoding($url, 255));
		$trackbacklog = new TrackbackLog;
		$trackbacklog->entry = $entryId;
		$trackbacklog->url = POD::escapeString(UTF8::lessenAsEncoding($url, 255));
		$trackbacklog->add();

		$xmls = new XMLStruct();
		if ($xmls->open($request->responseText)) {
			$blognewsid = $xmls->getValue('/response/id');
			$error = $xmls->getValue('/response/error');
			if ($error == 0 && Validator::id($blognewsid)) {
				$data = DBModel::getInstance();
				$data->reset('DaumView');
				$data->setAttribute('blognewsid', $blognewsid, true);
				$data->setAttribute('blognewsid_checked', Timestamp::getUNIXtime());
				$data->setQualifier('blogid', 'eq', $blogid);
				$data->setQualifier('entryid', 'eq', $entryId);
				@$data->update();
			}
		}
		return true;
	}
	return false;
}

// interface
function DaumView_HandleSetCategory() {
	$categoryid = $_REQUEST['categoryId'];
	$channel = $_REQUEST['channel'];
	$entryid = $_REQUEST['entryId'];
	if(DaumView_setDaumview($categoryid, $channel, $entryid))
		echo($categoryid);
	else
		echo ('-1');
	return ;
}

function DaumView_OnConfigChanged($data){
	requireComponent('Textcube.Function.misc');
	$cfg = misc::fetchConfigVal($data);

	requireComponent('Needlworks.Cache.PageCache');
	$cache = new PageCache;
	$cache->name = 'daumview_bestnews';
	$cache->purge();
	$cache->name = 'daumview_mynews';
	$cache->purge();
	return true;
}

function DaumView_OnAddPostEditorToolbox($target, $mother) {
	global $pluginURL;
	global $entry;

	$context = Model_Context::getInstance();
	$data = DBModel::getInstance();
	$blogid = $context->getProperty('blog.id');

	$entryid = $entry['id'];

	$data->reset('DaumView');
	$data->setQualifier('blogid','eq',$context->getProperty('blog.id'));
	$data->setQualifier('entryid','eq',$entryid);
	$daumview = $data->getRow();
	$categoryInfo = is_null($daumview) ? array('category' => 0,'send'=> 0,'categoryid'=> 0):$daumview;

	if( $entryid == 0 ){
		// 임시로 작성한 글 같은 경우 카테고리 삭제
		$userid = $context->getProperty('user.id');
		$data->reset('DaumView');
		$data->setQualifier('blogid', 'eq', $blogid);
		$data->setQualifier('entry', 'eq', 0);
		$data->delete();
	}else{
		// 공개 상태에서 DaumView 뉴스 정보가 없으면 삭제
		if(!DaumView_getDaumviewidByPermalink($entryid) && $entry['visibility'] > 2)
			DaumView_deleteDaumview($entryid);
	}

	$xml = DaumView_getChannels();
	$xmls = new XMLStruct();
	if ($xmls->open($xml, 'EUC-KR')) {
		ob_start();
		if ($xmls->getValue('/result/head/code') == "200") { 
			$plugName = trim(str_replace("{$context->getProperty('service.path')}/plugins/", '', $pluginURL), '/');
?>
	<script type="text/javascript">
	//<![CDATA[
	function setCategory(v) {
		try{
			var values = v.split('|');
			if (values[1].length != 0) {
				var oHttp = createHttp();
				oHttp.open("GET", "<?php echo $context->getProperty('uri.blog')?>/owner/plugin/adminHandler?name=<?php echo $plugName ?>/DaumView_HandleSetCategory&categoryId="+values[0]+"&channel="+values[1]+"&entryId="+<?php echo $entryid;?>, false);
				oHttp.send("");
			}
		} catch (e) {
			window.status = e.messge;
		}
	}

	function deleteCategory() {
		alert('My View 목록에서 직접 지우세요.\n(My View목록에서 삭제후, 블로그 글을 공개상태 유지 + 에디트상태에 들어가면 지워집니다.)\n주의! DaumView 퍼머링크, 조회수와 추천수도 같이 지워집니다.');
		window.open("http://v.daum.net/my");
		return false;
	}
	//]]>
	</script>

	<div id='layout_daumview_category' style="padding:5px 0 0 10px;">
		<strong>DaumView로 보내기</strong> :
		<select id='daumview_category' name='daumview_category' onchange='setCategory(this.value);' >
			<option value='0|'>선택하세요</option>
<?php
			$one_depth_categories = $xmls->selectNodes('/result/entity/category');
			foreach($one_depth_categories as $one_depth_category) {
				$one_depth_category_name = $one_depth_category['name'][0]['.value'];
				foreach($one_depth_category['list'][0]['category'] as $two_depth_category) {
					$id = $two_depth_category['id'][0]['.value'];
					$url = $two_depth_category['trackback_url'][0]['.value'];
					$two_depth_category_name = $two_depth_category['name'][0]['.value'];
					$channel = str_replace("http://v.daum.net/trackback/", '', $url);
?>
			<option value='<?php echo $id;?>|<?php echo $channel;?>' <?php echo ( ($id == $categoryInfo['categoryid'] )?'selected =\'selected\' ':'');?>><?php echo $one_depth_category_name .'-'.$two_depth_category_name;?></option>
<?php
				}
			}
?>
		</select>
			<? if (!empty($categoryInfo['send'])): ?>
		<a href="http://v.daum.net/my" style="font-weight: bold;" onclick="alert('My View 목록에서 직접 지우세요.\n(My View목록에서 삭제후, 블로그 글을 공개상태 유지 + 에디트상태에 들어가면 지워집니다.)\n주의! DaumView 퍼머링크, 조회수와 추천수도 같이 지워집니다.');window.open(this.href);return false;">삭제</a>
			<? endif; ?>
<?php
		} else {
			echo '<span class="notice" style="color:red;">다음View로부터 카테고리 정보를 가져오지 못했습니다.</span>';
		}
?>
	</div>
<?php
		$ob = ob_get_contents();
		ob_end_clean();
	}
	$target .= $ob;
	return $target;
}

function DaumView_OnAddPost($target, $mother){
	global $user;	

	$context = Model_Context::getInstance();
	$data = DBModel::getInstance();
	$userid = $user['id'];
//	$userid = $context->getProperty('user.id');

	$data->reset('DaumView');
	$data->setAttribute('entryid', $target);
	$data->setQualifier('blogid', 'eq', $context->getProperty('blog.id'));
	$data->setQualifier('userid', 'eq', $userid);
	$data->setQualifier('entryid', 'eq', 0);
	@$data->update();

	return $target;
}

function DaumView_OnDeletePost($target, $mother){
	DaumView_deleteDaumview($target);
	return $target;
}

function SyndicateToDaumView($target, $mother) {
	DaumView_syncDaumview($target);
	return $target;
}

function DaumView_RecommandWidget($target, $mother){
	global $configVal;

	requireComponent("Textcube.Function.misc");
	$data = misc::fetchConfigVal($configVal);
	if(is_null($data)) {
		$data['showWidget'] = 'show';
		$data['widgetKind'] = 1;
	}

	$daumviewid = DaumView_getDaumviewid($mother);
	if(strcmp($data['showWidget'],'hide') == 0 || is_null($daumviewid)) return $target;

	switch($data['widgetKind']) {
		case 1:
			$width = 405;
			$height = 95;
			$iframe_url = "http://api.v.daum.net/widget1?nid=";
			break;
		case 2:
			$width = 80;
			$height = 95;
			$iframe_url = "http://api.v.daum.net/widget1?nid=";
			break;
		case 3:
			$width = 140;
			$height = 45;
			$iframe_url = "http://api.v.daum.net/widget3?nid=";
			break;
		default:
			break;
	}

	switch($data['widgetKind']) {
		case 1:
		case 2:
		case 3:
			$widget = "<div style=\"margin: 20px 0pt; width: 100%; text-align: center;\">
<iframe src=\"{$iframe_url}{$daumviewid}\" width=\"{$width}\" height=\"{$height}\" frameborder=\"0\"/></iframe>
</div>";
			break;
		default:
			$widget = "";
			break;
	}

	return $target.$widget;	
}

function DaumView_getSidebarView($url, $length) {
	global $configVal;
	global $owner;

	requireComponent('Textcube.Function.misc');
	$data = misc::fetchConfigVal($configVal);
	$data['link_kind'] = isset($data['link_kind']) ? $data['link_kind'] : 'infolink' ;
	$data['row_count'] = isset($data['row_count']) ? $data['row_count'] : 5;

	$result= '';
	requireComponent("Eolin.PHP.HTTPRequest");	
	$request = new HTTPRequest($url);
	$request->timeout = 1;
	$request->referer = !isset($_SERVER['HTTP_REFERER'])? '' : $_SERVER['HTTP_REFERER'];
	$xml = $request->send()? $request->responseText : null;

	if (!is_null($xml)) {
		$xmls = new XMLStruct();
		if ($xmls->open($xml, 'EUC-KR')) {
//			$result_code = $xmls->getValue('/result/head/code');
			if ($xmls->getValue('/result/head/code') == '200' || $xmls->getValue('/result/message') == 'PROCESS_OK') {
				$news = $xmls->selectNodes('/result/entity/news');
				if(!is_array($news) ) return $result;

				$result .= "<ol>\r\n";
				$count = 0;
				foreach ($news as $new) {
					$title = $new['title'][0]['.value'];
					$link = $new['link'][0]['.value'];
					$infolink = $new['infolink'][0]['.value'];
					$tinylink = $new['tinylink'][0]['.value'];
					$regdate = $new['reg_date'][0]['.value'];

					if ($data['link_kind'] == 'infolink') {
						$result .= "<li><a href=\"{$infolink}\" onclick=\"window.open(this.href);return false;\" title=\"".str_replace("\"", "&quot;", $title)."\">".UTF8::lessen($title,  $length)."</a></li>\r\n";
					} else if ($data['link_kind'] == 'tinylink') {
						$result .= "<li><a href=\"{$tinylink}\" onclick=\"window.open(this.href);return false;\" title=\"".str_replace("\"", "&quot;", $title)."\">".UTF8::lessen($title,  $length)."</a></li>\r\n";
					} else {
						$result .= "<li><a href=\"{$link}\" title=\"".str_replace("\"", "&quot;", $title)."\">".UTF8::lessen($title,  $length)."</a></li>\r\n";
					}
					if ($count++ > $data['row_count']) break;
				}
				$result .= "</ol>\r\n";
			}
		}
	}
	return $result;
}

function DaumView_BestNews($target) {
	global $configVal;

	if (isset($target['preview']))
		return "DaumView의 베스트 기사 목록을 보여줍니다.";

	requireComponent('Textcube.Core');
	requireComponent('Needlworks.Cache.PageCache');
	$cache = new PageCache;
	$cache->name = 'daumView_bestnews';

	if($cache->load()) { //If successful loads
		if((time() - $cache->dbContents) < 3600)	// refresh time check
			return $cache->contents;
	}

	requireComponent("Textcube.Function.misc");
	$data = misc::fetchConfigVal($configVal);
	if(is_null($data)){
		$data['bestnews_header'] = "<div id=\"daumview_bestnews\" class=\"recent module\">\n<h3>DaumView 베스트</h3>";
		$data['bestnews_footer'] = "</div>";
		$data['bestnews_length'] = 25;
	}

	$target = $data['bestnews_header'];
	$target .= DaumView_getSidebarView('http://api.v.daum.net/open/best_news.xml', $data['bestnews_length']);
	$target .= $data['bestnews_footer'];

	$cache->contents = $target;
	$cache->dbContents = Timestamp::getUNIXtime();
	$cache->update();
	unset($cache);

	return $target;
}

function DaumView_MyNews($target) {
	global $configVal;

	if (isset($target['preview']))
		return "내가 송고한 DaumView 기사 목록을 보여줍니다.";

	requireComponent('Textcube.Core');
	requireComponent('Needlworks.Cache.PageCache');
	$cache = new PageCache;
	$cache->name = 'daumview_mynews';

	if($cache->load()) { //If successful loads
		if((time() - $cache->dbContents) < 3600)	// refresh time check
			return $cache->contents;
	}

	$context = Model_Context::getInstance();

	requireComponent("Textcube.Function.misc");
	$data = misc::fetchConfigVal($configVal);
	if(is_null($data)){
		$data['mynews_header'] = "<div id=\"DV_mynews\" class=\"recent module\">\n<h3>나의 DaumView뉴스</h3>";
		$data['mynews_footer'] = "</div>";
		$data['mynews_length'] = 25;
	}

	$target = $data['mynews_header'];
	$target .= DaumView_getSidebarView('http://api.v.daum.net/open/my_news.xml?blogurl='. rawurlencode($context->getProperty('uri.default')), $data['mynews_length']);
	$target .= $data['mynews_footer'];

	$cache->contents = $target;
	$cache->dbContents = Timestamp::getUNIXtime();
	$cache->update();
	unset($cache);

	return $target;
}

function DaumView_Banner($target){
	global $configVal;

	if (isset($target['preview']))
		return "DaumView 공식 배너.";

	requireComponent("Textcube.Function.misc");
	$data = misc::fetchConfigVal($configVal);
	if(is_null($data)){
		$data['banner_header'] = "<p style=\"text-align:center; margin: 0 auto; padding: 0;\">";
		$data['banner_footer'] = "</p>";
	}

	$target = $data['banner_header'];
	$target .= "<a href=\"http://v.daum.net\" onclick=\"window.open(this.href); return false;\"><img src=\"http://img-section.hanmail.net/blognews/banner/big.gif\" alt=\"DaumView\" width=\"162\" height=\"52\" /></a>";
	$target .=$data['bannerFooter'];

	return $target;
}
?>
